/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2015 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#if !defined (__APPSTREAM_GLIB_H) && !defined (AS_COMPILATION)
#error "Only <appstream-glib.h> can be included directly."
#endif

#ifndef __AS_APP_GETTEXT_H
#define __AS_APP_GETTEXT_H

#include <glib.h>
#include <gio/gio.h>

#include "as-app.h"

G_BEGIN_DECLS

/**
 * AsAppBuilderFlags:
 * @AS_APP_BUILDER_FLAG_NONE:			No special actions to use
 * @AS_APP_BUILDER_FLAG_USE_FALLBACKS:		Fall back to guesses where required
 *
 * The flags to use when building applications.
 **/
typedef enum {
	AS_APP_BUILDER_FLAG_NONE,
	AS_APP_BUILDER_FLAG_USE_FALLBACKS	= 1,	/* Since: 0.5.8 */
	/*< private >*/
	AS_APP_BUILDER_FLAG_LAST,
} AsAppBuilderFlags;

gboolean	 as_app_builder_search_translations	(AsApp		*app,
							 const gchar	*prefix,
							 guint		 min_percentage,
							 AsAppBuilderFlags flags,
							 GCancellable	*cancellable,
							 GError		**error);
gboolean	 as_app_builder_search_kudos		(AsApp		*app,
							 const gchar	*prefix,
							 AsAppBuilderFlags flags,
							 GError		**error);
gboolean	 as_app_builder_search_provides		(AsApp		*app,
							 const gchar	*prefix,
							 AsAppBuilderFlags flags,
							 GError		**error);

G_END_DECLS

#endif /* __AS_APP_GETTEXT_H */
